# Pouch cell parameters

Parameters for an A123 LFP cell, from the paper

> Lain, M. J., Brandon, J., & Kendrick, E. (2019). Design Strategies for High Power vs. High Energy Lithium Ion Cells. [Batteries](https://doi.org/10.3390/batteries5040064), 5(4), 64.
